ChannelParameters

Struct ChannelParameters 

pub struct ChannelParameters {
    pub channel_mode: Option<ChannelMode>,
    pub max_rx_packet_size: Option<u16>,
    pub security_requirements: Option<SecurityRequirements>,
    pub flush_timeout: Option<i64>,
    /* private fields */
}
The set of parameters to use or that were used to establish an L2CAP connection-oriented channel.

Fields

channel_mode: Option<ChannelMode>

Optional. For BR/EDR: If not provided, BASIC will be used. For LE: If not provided, LE_CREDIT_BASED_FLOW_CONTROL will be used.

max_rx_packet_size: Option<u16>

Maximum packet size this profile is capable of accepting. Must be >= 48. Optional. If not provided, the size will be determined by the Bluetooth system. No guarantees are given regarding the size selected.

security_requirements: Option<SecurityRequirements>

For BR/EDR: Minimum security requirements a link must have before this channel can be created. The requirements provided here will be attempted with the peer before the channel is established. If a peer cannot provide the requirements, the channel is closed. Optional. If not provided, then the only security property guaranteed is encryption.

For LE: Unused, must not be present.

flush_timeout: Option<i64>

For BR/EDR: The flush timeout indicates the maximum amount of time a data packet should be buffered in the controller before it is dropped. A flush timeout of infinity can be used to mark packets as flushable without any particular flush timeout. Range: 1ms - 1,279ms (or ∞). Rounded down. Optional. If not provided, no flush timeout and packets are not flushable.

For LE: Unused, must not be present.